function Gt=antradpat(wave,Waz,Wel,SLLdb,BLdb,Thrad,Phrad)
% computes the antenna radiation pattern for the specified angles
% scaled Taylor in azimuth with SLLdb (phi=90)
% antenna is approximated by an array with 5 isotropic elements
% per wavelength in azimuth
% uniform aperture function (sinc) is used in elevation (phi=0)
rad=pi/180;
bk=2*pi/wave;
BL=10^(BLdb/20);
% elevation pattern factor (phi = 0 plane)
Fel=1;
arg1=bk*sin(Thrad)*cos(Phrad)/2;
if abs(arg1)>1e-5
   Fel=abs(sin(Wel*arg1)/arg1/Wel)^2;
end
% azimuth pattern factor (phi = 90 plane)
Naz=floor(Waz/(0.5*wave))+1;   
if mod(Naz,2)~=0, Naz=Naz+1; end % Naz must be even
if Naz<6, Naz=6; end  % use at least 6 elements
dspc=Waz/(Naz-1);
arg2=bk*sin(Thrad)*sin(Phrad);
if SLLdb <= -15
    nbar=max(5,floor(Naz/5));
    amp=tayl(Naz,SLLdb,nbar);
else 
    amp=ones(1,Naz);
end
% calculate aperture efficiency
s1=0; s2=0;
sa=sum(amp); sb=sum(amp.^2);
eta=sa^2/Naz/sb;
Fmax=sum(amp).^2;
D=[0:Naz-1]*dspc;
Exp=exp(j*D*arg2);
Faz=abs(sum(amp.*Exp))^2;
Fnorm=Faz/Fmax;
% suppress the backlobe to desired level
EF=((1-BL)*abs(cos(Thrad/2)^2)+BL)^2;   
Gt=4*pi*Waz*Wel*Fnorm*Fel*EF/wave^2*eta;