function [thetaja,phija]=earth2ant(xt,yt,ht,xj,yj,hj,hr);
% radar at height hr above the earth coordinate system origin
% jammer at xj,yj,hj
% target at xt,yt,ht
% transform in the plane of the radar (zt=ht-hr, zj=hj-hr)
% return jammer angles (theta,phi) in the antenna coordinate system
zt=ht-hr;
Dt=[xt; yt; zt];
alpha=atan2(yt,xt);
% target range
Rt=sqrt(xt^2+yt^2+zt^2);
beta=atan2(Rt,zt);
% jammer location
zj=hj-hr;
Dj=[xj; yj; zj];

% align antenna x axis with the target azimuth (rotate about z axis)
% T1: earth to antenna transformation matrix
T1=[cos(alpha) sin(alpha) 0; -sin(alpha) cos(alpha) 0; 0 0 1];

% T2: tilt back antenna in target azimuth (rotate about ya axis)
T2=[cos(beta) 0 -sin(beta); 0 1 0; sin(beta) 0 cos(beta)];

Dja=T2*(T1*Dj);
xja=Dja(1); yja=Dja(2); zja=Dja(3);
rja=sqrt(xja^2+yja^2);
% theta and phi angles in radians
phija=atan2(yja,xja);
thetaja=atan2(rja,zja);



