function fig = radjam(command_str);

% Main GUI for radjam.m (version 2.0)
% Project: radar and jamming simulation version 2.0
% Description: This program calculates the detection contours 
%			of a target when jamming is present. 
%			Radar, jammer and target parameters can be varied.
% Author:  Prof. David C. Jenn 
% Date:   July 2002 
% Place: NPS

if nargin == 0
   command_str = 'initialize';
end

% Initialize the GUI
if strcmp(command_str,'initialize')
   h_figs = get(0,'children');
   fig_exists = 0;
   for fig = h_figs'
      fig_exists = strcmp(get(fig,'Tag'),'radjam');
      if fig_exists
         figure(fig);
         return;
      end
   end
end

h0 = figure('Units','normalized', ...
	'Color',[0.8 0.8 0.8], ...
	'FileName','radjam.m', ...
	'MenuBar','none', ...
	'Name',' RADAR AND JAMMING SIMULATION (RADJAM V2.0)', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432], ...
	'PaperUnits','points', ...
	'Position',[0.39453125 0.19140625 0.5673828125 0.65234375], ...
	'Resize','off', ...
	'Tag','radjam', ...
	'ToolBar','none');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'ListboxTop',0, ...
	'Position',[0.3494 0.5329 0.62 0.442], ...
	'Style','frame', ...
	'Tag','Frame1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'ListboxTop',0, ...
	'Position',[0.3494 0.1178 0.62 0.3992], ...
	'Style','frame', ...
	'Tag','Frame2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'ListboxTop',0, ...
	'Position',[0.021 0.117 0.32 0.857], ...
	'Style','frame', ...
	'Tag','Frame3');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.43 0.92 0.24 0.034], ...
	'String','Jammer Parameters', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.777 0.92 0.12 0.034], ...
	'String','Target', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.73 0.7 0.18 0.034], ...
	'String','Ground Reflection', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.36 0.85 0.12 0.034], ...
	'String','Height (m)', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.78 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.477 0.85 0.12 0.034], ...
	'String','Range (km)', ...
	'Style','text', ...
	'Tag','StaticText1');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.61 0.845 0.11 0.04], ...
	'String','Az (deg)', ...
	'Style','text', ...
	'Tag','StaticText5');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.38 0.705 0.19 0.045], ...
	'String','Power (W)', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.38 0.628 0.19 0.045], ...
	'String','Gain (dB)', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.38 0.55 0.19 0.045], ...
	'String','Noise BW (MHz)', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.71 0.76 0.14 0.045], ...
	'String','RCS (dBsm)', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.71 0.84 0.14 0.045], ...
	'String','Height (m)', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.71 0.628 0.14 0.045], ...
	'String','Magnitude', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.71 0.55 0.13 0.045], ...
	'String','Phase (deg)', ...
	'Style','text', ...
	'Tag','StaticText2');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.39 0.39 0.18 0.04], ...
	'String','Antenna  efficiency', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.39 0.319 0.2 0.034], ...
	'String','Azimuth length (m)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.39 0.245 0.2 0.034], ...
	'String','Elevation length (m)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.39 0.175 0.2 0.034], ...
	'String','Height (m)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'FontWeight','bold', ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.45 0.46 0.22 0.034], ...
	'String','Radar Antenna', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'ListboxTop',0, ...
	'Position',[0.72 0.28 0.23 0.04], ...
	'String','Plot antenna pattern?', ...
	'Style','text', ...
	'Tag','StaticText5');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.7, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.725 0.15 0.12 0.034], ...
	'String','Freq (GHz)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.8, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.71 0.445 0.15 0.03], ...
	'String','Rel SLL (dB)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.8, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.71 0.365 0.14 0.03], ...
	'String','Backlobe (dB)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[0.062 0.91 0.23 0.045], ...
	'String','Calculation Data', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.86 0.21 0.04], ...
	'String','Start (deg)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.8 0.21 0.04], ...
	'String','Stop (deg)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.74 0.21 0.04], ...
	'String','Rng|Az step (m|deg)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.68 0.24 0.04], ...
	'String','Grid max range (km)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.6, ...
	'FontWeight','bold', ...
	'ListboxTop',0, ...
	'Position',[0.062 0.61 0.23 0.045], ...
	'String','Radar Parameters', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.55 0.21 0.04], ...
	'String','SNRmin (dBm)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.49 0.21 0.04], ...
	'String','Power (dBW)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.42 0.21 0.04], ...
	'String','Proc gain (dB)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.36 0.21 0.04], ...
	'String','Noise BW (MHz)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.29 0.21 0.04], ...
	'String','Pulsewidth (micros)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.22 0.21 0.04], ...
	'String','Receiver Te (K)', ...
	'Style','text', ...
	'Tag','StaticText4');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName','Arial', ...
	'FontSize',0.65, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[0.035 0.15 0.21 0.04], ...
	'String','Antenna TA (K)', ...
	'Style','text', ...
	'Tag','StaticText4');
% start edit boxes here
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Jamhgt;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.37 0.78 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Jamhgt');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Jampow;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.599 0.7 0.0861 0.0579], ...
	'String','10', ...
	'Style','edit', ...
	'Tag','Jampow');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Jamgain;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.599 0.625 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Jamgain');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Jamnoise;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.599 0.55 0.0861 0.0579], ...
	'String','10', ...
	'Style','edit', ...
	'Tag','Jamnoise');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Jamrng;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.485 0.78 0.0861 0.0579], ...
	'String','10', ...
	'Style','edit', ...
	'Tag','Jamrng');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Jamaz;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.599 0.78 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Jamaz');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad RCSdb;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.86 0.76 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','RCSdb');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad tgthgt;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.86 0.84 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','tgthgt');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Gmag;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.86 0.625 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Gmag');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Gfaz;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.86 0.55 0.0861 0.0579], ...
	'String','180', ...
	'Style','edit', ...
	'Tag','Gfaz');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Slldb;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.85 0.43 0.0861 0.057], ...
	'String','-15', ...
	'Style','edit', ...
	'Tag','Slldb');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Blldb;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.85 0.35 0.0861 0.057], ...
	'String','-20', ...
	'Style','edit', ...
	'Tag','Blldb');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Anteff;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.5938 0.38 0.0861 0.0579], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','Anteff');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Wazim;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.5938 0.305 0.0861 0.0579], ...
	'String','5', ...
	'Style','edit', ...
	'Tag','Wazim');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Welev;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.5938 0.2316 0.0861 0.0579], ...
	'String','3', ...
	'Style','edit', ...
	'Tag','Welev');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad radhgt;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.5938 0.16 0.0861 0.0579], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','radhgt');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Freq;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.845 0.14 0.1033 0.0519], ...
	'String','0.3', ...
	'Style','edit', ...
	'Tag','Freq');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Teff;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.21 0.075 0.0519], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Teff');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad TAnt;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.14 0.075 0.0519], ...
	'String','370', ...
	'Style','edit', ...
	'Tag','TAnt');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Tau;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.28 0.075 0.0519], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','Tau');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad BWR;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.35 0.075 0.0519], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','BWR');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Gproc;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.42 0.075 0.0519], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','Gproc');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad Ptx;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.485 0.075 0.0519], ...
	'String','10', ...
	'Style','edit', ...
	'Tag','Ptx');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad SNRMIN;', ...
	'FontName','Arial', ...
	'FontSize',0.55, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.55 0.075 0.051], ...
	'String','0', ...
	'Style','edit', ...
	'Tag','SNRMIN');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad AStep;', ...
	'FontName','Arial', ...
	'FontSize',0.55, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.74 0.075 0.05], ...
	'String','2', ...
	'Style','edit', ...
	'Tag','AStep');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad AStop;', ...
	'FontName','Arial', ...
	'FontSize',0.55, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.8 0.075 0.05], ...
	'String','180', ...
	'Style','edit', ...
	'Tag','AStop');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad AStart;', ...
	'FontName','Arial', ...
	'FontSize',0.55, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.86 0.075 0.05], ...
	'String','-180', ...
	'Style','edit', ...
	'Tag','AStart');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad MaxRng;', ...
	'FontName','Arial', ...
	'FontSize',0.55, ...
	'ListboxTop',0, ...
	'Position',[0.245 0.68 0.075 0.05], ...
	'String','10', ...
	'Style','edit', ...
	'Tag','MaxRng');
% pushbuttons
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Callback','setrad Print;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.33 0.0279 0.157 0.06], ...
	'String','Print', ...
	'Tag','Print');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Callback','setrad Close;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.56 0.0279 0.157 0.06], ...
	'String','Close', ...
	'Tag','Close');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Callback','hlpmain;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.7941 0.0279 0.157 0.06], ...
	'String','Help', ...
	'Tag','Help');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Callback','setrad Calculate;', ...
	'FontName','Arial', ...
	'FontSize',0.5, ...
	'ListboxTop',0, ...
	'Position',[0.0377 0.0279 0.2083 0.06], ...
	'String','Calculate', ...
	'Tag','Calculate');
h1 = uicontrol('Parent',h0, ...
	'Units','normalized', ...
	'FontUnits','normalized', ...
	'BackgroundColor',[1 1 1], ...
	'Callback','setrad antpat', ...
	'FontName','Arial', ...
	'FontSize',0.4, ...
	'ListboxTop',0, ...
	'Position',[0.75 0.21 0.17 0.06], ...
	'String',['Yes ';'No  '], ...
	'Style','popupmenu', ...
	'Tag','antpat', ...
	'Value',1);
if nargout > 0, fig = h0; end
