% program radjam.m  #### PC version ####
% MODIFIED TO INCLUDE CLOSED FORM CONTOUR CASE
% has the NEW ANTENNA MODEL (TAYLOR) INSERTED FOR VALIDATION
% radar and jammer (jammer antenna pointed at radar; radar pointed at target)
% all units in meters unless otherwise noted
% radar-target LOS is the x axis; jammer is at angle phij from x axis
clear
rad=pi/180;
% RADAR PARAMETERS **************************************************************
Pt=1e3;          % radar trasmitter power
hr=0;           % radar height
Waz=3;           % radar antenna az aperture in m (sinc pattern)
Wel=1;           % radar antenna el aperture in m (sinc pattern)
TA=1000;         % antenna temperature
Te=1000;         % effective temperature of radar receiver
Ts=TA+Te;        % radar system noise temperature
er=0.8;          % radar antenna efficiency
freq=1e9;        % frequency
c=3e8;           % velocity of light
wave=c/freq;     % wavelength
k=2*pi/wave;     % wave number (propagation constant)
Gpdb=20;         % radar processing gain in db
Gp=10^(Gpdb/10);
tau=1e-6;        % radar pulse width
Bn=1/tau;        % radar noise bandwidth
boltz=1.38e-23;  % Boltzman's constant
No=boltz*Ts*Bn;  % noise power
SNRmindb=10;     % threshold SNR
SNRmin=10^(SNRmindb/10);
Smin=SNRmin*No;  % minimum detectable signal (MDS) in db
%------------- NEW ANTENNA MODEL (TAYLOR) ---------------------
% plot an antenna pattern for reference
 it=0; 
 SLLdb=-40; BLdb=-60;
 BL=10^(BLdb/20);
   for ang=-180:.5:180
       Thrad=ang*rad; Phrad=0;  it=it+1; A(it)=ang;
% elevation pattern factor (phi = 90 plane)
Fel=1;
arg1=k*sin(Thrad)*sin(Phrad)/2;
if abs(arg1)>1e-5
   Fel=abs(sin(Wel*arg1)/arg1/Wel)^2;
end
% azimuth pattern factor (phi = 90 plane)
Naz=floor(Waz/(0.5*wave));   % must be even
if Naz<6, Naz=6; end  % use at least 6 elements
dspc=Waz/(Naz-1);
arg2=k*sin(Thrad)*cos(Phrad);
if SLLdb <= -15
    nbar=max(5,floor(Naz/5));
    amp=tayl(Naz,SLLdb,nbar);
else 
    amp=ones(1,Naz);
end
% calculate aperture efficiency
s1=0; s2=0;
sa=sum(amp); sb=sum(amp.^2);
eta=sa^2/Naz/sb;
Fmax=sum(amp).^2;
D=[0:Naz-1]*dspc;
Exp=exp(j*D*arg2);
Faz=abs(sum(amp.*Exp))^2;
% suppress the backlobe to desired level (not included in eta)
EF=((1-BL)*abs(cos(Thrad/2))^2+BL)^2;   
G(it)=10*log10(4*pi*Waz*Wel*Faz*Fel*EF/Fmax/wave^2*eta);
   end
   figure(1),clf
   polardb(A,G,'k-')
   title('Antenna Pattern')
 
% TARGET PARAMETERS **************************************************************
ht=0;        % target altitude
rcsdb=10;      % target rcs
rcs=10^(rcsdb/10);
% max detection range with no jamming
G0=4*pi*Waz*Wel*er*eta/wave^2;   % max gain of radar antenna is on target
RRmax=((Pt*G0^2*rcs*wave^2*Gp)/(4*pi)^3/SNRmin/No)^(1/4);
disp(['Max detection range without jamming = ',num2str(RRmax/1e3),' km'])

% JAMMER PARAMETERS **************************************************************
Gjdb=3;        % jammer gain in direction of radar (in db)
Gj=10^(Gjdb/10);
hj=0;        % jammer altitude
Bj=1e6;        % jammer bandwidth
Pj=1e0;        % jammer transmitter power

% compute contours of Rmax by computing the SNR over a rectangular grid
% target range and angle change; jammer location fixed
   Rj=10000;      % jammer range fixed
   angj=0*rad;    % jammer angle fixed
   xj=Rj*cos(angj); yj=Rj*sin(angj);
   Rtmax=10000;  % max/min target range
   dRt=25;      % increment in target range
   x=[-Rtmax:dRt:Rtmax]; y=x;
N=length(x);
% earth reflection coefficent for multipath (complex quantity)
gam=0;
% if gam=0 then use the closed form solution since only one
% contour exists
if gam==0
  ic=0;
  for phi=-180:1:180
   ic=ic+1;
   P(ic)=phi*rad; 
   dang=angj-phi*rad;
   Fel=1;
   Naz=floor(Waz/(0.5*wave));   % must be even
   if Naz<6, Naz=6; end  % use at least 6 elements
   dspc=Waz/(Naz-1);
   arg2=k*sin(dang)*cos(0);
   if SLLdb <= -15
    nbar=max(5,floor(Naz/5));
    amp=tayl(Naz,SLLdb,nbar);
else 
    amp=ones(1,Naz);
end
% calculate aperture efficiency
s1=0; s2=0;
sa=sum(amp); sb=sum(amp.^2);
eta=sa^2/Naz/sb;
Fmax=sum(amp).^2;
D=[0:Naz-1]*dspc;
Exp=exp(j*D*arg2);
Faz=abs(sum(amp.*Exp))^2;
Fnorm=Faz/Fmax;
% suppress the backlobe to desired level
EF=((1-BL)*abs(cos(dang/2))^2+BL)^2;   
Grj=4*pi*Waz*Wel*Fnorm*Fel*EF/wave^2*eta;
       R(ic)=((Pt*G0^2*rcs*wave^2*Gp)/(4*pi)^3/SNRmin/...
        (Pj*Gj*Grj*(Bn/Bj)*(wave/4/pi/Rj)^2+No) )^(1/4);
  end
  figure(2),clf
% set a maximum detection range ring (ring spacing drng)
  drng=10;
  Rkm0=(floor(max(R)/1e3/10)+1)*10;
  polar(P,R/1e3,'k-')
  hold on
  polar(Rkm0,0)
  text(0,0,'R') 
  text(xj/1000,yj/1000,'J')  % jammer range fixed -- label it
  title('Detection Range Contour (km)')
 end
% if gam>0 use contours since multiple rings may exist
if abs(gam)>0
% two-dimensional matrices of range and angle
X=ones(N,1)*x;
Y=(ones(N,1)*y)';
Phi=atan2(Y,X);
Rho=sqrt(X.^2+Y.^2);
% compute signal power
for i=1:N
   for m=1:N
% target range and angle; jammer fixed
   	  Rt=Rho(i,m); angt=Phi(i,m); 	
% radar antenna gain in the direction of the jammer 
% the main beam is assumed to be tracking the target if target is moving
% OLD ANTENNA MODEL
% see if jammer is in the forward hemisphere of radar antenna
%		if abs(dang)<=pi/2,
%           Sinc=1;
%		   if abs(arg)>1e-5, Sinc=abs(sin(arg)/arg); end
%	    end
%        Grj=(Gmax*((AA*Sinc)^2+...
%		   abs(BB*cos(arg/Waz)*sin(dang))^2)*abs(cos(dang))+MIN);
        dang=angj-angt;
		  arg=k*Waz*sin(dang)/2;
        Sinc=1;
  	     if abs(arg)>1e-4, Sinc=sin(arg)/arg; end
        if abs(dang) <= pi/2, Gmax=G0; FF=1; end
        if abs(dang) > pi/2, Gmax=G0; FF=sin(dang); end
        Grj=Gmax*(FF*Sinc)^Nant;       
% radar/target path-gain factor 
        if Rt <= 1e-4, Fr=NaN; end
        if Rt > 1e-4
           Fr=abs(1+gam*exp(-j*k*(2*hr*ht/Rt)));
	    end
	    if i==(N+1)/2, PPF(m)=Fr; RR(m)=Rt; end
% radar/jammer path-gain factor
		  Fj=abs(1+gam*exp(-j*k*(2*hr*hj/Rj)));
% target signal
        if Rt <= 1e-4, Pr=NaN; end
        if Rt > 1e-4
           Pr=Pt*G0^2*wave^2*rcs*Gp/(4*pi)^3/Rt^4*Fr^4;
        end
% jammer signal
		  Prj=Pj*Gj*wave^2*Grj*(Bn/Bj)/(4*pi*Rj)^2*Fj^4;
% signal to jammer plus noise ratio
	     SNR(i,m)=Pr/(Prj+No);
		 if Rho(i,m) > Rtmax, SNR(i,m)=NaN; end
	end
end

% plot contours of MDS
figure(2),clf
polar(0,Rtmax/1000)
hold on
snrdb=10*log10(SNR+1e-5); 
contour(X/1000,Y/1000,snrdb,[SNRmindb,SNRmindb],'k-')
text(0,0,'R'), 
text(xj/1000,yj/1000,'J')  % jammer range fixed -- label it
title(['SNR Contour Level is ',num2str(SNRmindb),...
 ' dB                                                              Range in km'])
% xlabel('Distance, km')
% ylabel('Distance, km')
axis square, axis equal
hold off
if abs(gam)>0
	figure(3)
	plot(RR/1000,40*log10(abs(PPF)+1e-4),'k-')
	title('Two-way radar/target PPF in dB')
	xlabel('Range, km')
	ylabel('PPF, dB')
end

end  
% superimpose antenna pattern on contour if isuper=1
isuper=0;
if isuper==1
   figure(2)
   hold on
% scale the pattern by patscl
   patscl=.6;
   polar(A*rad,(G-MINdb)*patscl)
   hold off
end

   











